curved_bottom_nav_bar library

Classes

CurvedBottomNavBar
A beautiful curved bottom navigation bar with floating selected icon animation
CurvedNavBarPainter
Custom painter that draws the curved bottom navigation bar
Model class for bottom navigation bar items